@@ -14,4 +14,7 @@ class Buddy:
         self.theme_uuid = data.get("themeUuid")
         self.display_icon = data.get("displayIcon")
         self.asset_path = data.get("assetPath")
-        self.raw_data = data
\ No newline at end of file
+        self.raw_data = data
+
+    def __str__(self):
+        return str(self.raw_data)
